# pyEmbedsSSSA Package

Package for Introduction to Programming and Machine Learning in Python

## Installing pyEmbedsSSSA
`pip install pyembeds-sssa`

## Course responsible:
- Andrea Vandin, andrea.vandin@santannapisa.it https://www.santannapisa.it/en/andrea-vandin
- Daniele Licari, daniele.licari@santannapisa.it https://www.linkedin.com/in/daniele-licari/

## Description:
The course introduces students to programming and data analysis, using python as a reference
language.
 - **Module 1** 
Introduces students to the fundamental principles of structured programming with basic applications to data processing

 - **Module 2**
Introduces the students to the components of typical data analysis processes and machine learning pipelines.
